# Version 0.1

# Copyright 2013 David McCormick
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Change history
# v0.1 - Create a vcsdeploy fact which tells us the versions of deploys on a server
#        Uses the /etc/vcsdeploys.yaml file maintained by the vcsdeployinfo type.
#  0.2 - Sort the vcsdeploy facts alphabetically by the path.

require 'yaml'

vcsdeployfacts = {}

if (File.exist?('/etc/vcsdeploys.yaml'))
  File.open('/etc/vcsdeploys.yaml') {|f| vcsdeployfacts = YAML.load(f) }
  vcsdeployfacts.each {|k,v|
    vcsdeployfacts.delete(k) if (!File.exists?(k)) 
  }
  # build up an array of facts
  out = ""
  vcsdeployfacts.keys.sort.each {|k|
    if (out == "")
      out = "#{k} #{vcsdeployfacts[k][:version]}"
    else
      out = "#{out}, #{k} #{vcsdeployfacts[k][:version]}"
    end
  }
  Facter.add('vcsdeploys') do
    setcode do
      out
    end
  end
end


