
# Version 0.2

# Copyright 2013 David McCormick
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Change history
# v0.1 - initial version, super simple type intended to be used to pass information
# 	 back from vcsdeploy to a server so you can see the versions being deployed.
# v0.2 - use a yaml file /etc/vcsdeploys.yaml to store the information about the 
#     deploys and so it doesn't interfere with the check out and can be read
#     to provide facts.

require 'fileutils'
require 'yaml'

Puppet::Type.type(:vcsdeployinfo).provide(:default) do
  desc "The default provider for conveying vcsdeploy version information..."

  def create 
    @vcsdeploys[@resource[:path]] = { 
      :source => @resource[:source],
      :version => @resource[:version],
    }
    File.open('/etc/vcsdeploys.yaml',"w") {|f| YAML::dump(@vcsdeploys,f) }
  end

  def destroy
    @vcsdeploys.delete(@resource[:path])
    File.open('/etc/vcsdeploys.yaml',"w") {|f| YAML::dump(@vcsdeploys,f) }
  end

  def exists?
    @vcsdeploys = {}
    if File.exists?('/etc/vcsdeploys.yaml')
      file = File.open('/etc/vcsdeploys.yaml','r')
      @vcsdeploys = YAML.load(file)
      file.close
    end
    @vcsdeploys.has_key?(@resource[:path])       
  end

  # check if the version installed matches the requested version.
  def version
    version = ""
    if (@vcsdeploys.has_key?(@resource[:path]))
      version = @vcsdeploys[@resource[:path]][:version]
    end
    version
  end

  # If the versions don't match, call the destroy and create to update to the latest version.
  def version=(newversion)	
    destroy
    create
  end
end
