# This type provides the 'vcsdeploy' type
# The type will deploy files on a server directly from a version control system such as svn.
#
# Version 0.9
# Dave McCormick
#
#  Copyright 2012 David McCormick
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#  http://www.apache.org/licenses/LICENSE-2.0
# 
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.
#

Puppet::Type.newtype(:vcsdeploy) do
  @doc = "Deploy files directly from a VCS such as svn or git."

  # Allow to be ensurable
  ensurable

  newparam(:name) do
    desc "A unique name for the deployment"
    isnamevar
    isrequired
  end

  newparam(:source) do
    desc "Where to checkout the files from"
  end

  newparam(:user) do
    desc "What user to check out as"
  end

  newparam(:pass) do
    desc "What password to use"
  end

  newparam(:path) do
    desc "Where to deploy to"
    isrequired
  end

  newparam(:owner) do
    desc "Owner of the deployed files/directories"
  end

  newparam(:group) do
    desc "Owner group of the deployed files/directories"
  end

  newparam(:dirmode) do
    desc "Unix file permissions of the deployed directories"
  end

  newparam(:filemode) do
    desc "Unix file permissions of the deployed files"
  end

  newparam(:selrange) do
    desc "SElinux range of the deployed files/directories"
  end

  newparam(:selrole) do
    desc "SElinux role of the deployed files/directories"
  end

  newparam(:seltype) do
    desc "SElinux type of the deployed files/directories"
  end

  newparam(:seluser) do
    desc "SElinux type of the deployed files/directories"
  end

  newparam(:scope) do
    desc "Scope passed from puppet master for use with templates."
  end

  newparam(:templates) do
    desc "Disable the template processing"
  end

  # version is a property as we expect this to 
  # change independently to create and destroy
  newproperty(:version) do
    desc "The version of the files that we require."
    isrequired
  end
end

